@@ -50,7 +50,7 @@ class Experiment:
             self.repo = MongoRepository(repository, db)
         # Pass in Class we build in 7.4
         elif type(repository).__name__ == "MongoRepository":
-            client = repository.client
+            client = repository.collection.database.client
             db = repository.collection._Collection__database._Database__name
             self.repo = MongoRepository(client, db)
         elif isinstance(repository, AbstractRepository):
@@ -82,7 +82,9 @@ class Experiment:
         )
         return r
 
-    def run_experiment(self, days: int, start: Optional[str] = None, assignment=False) -> dict:
+    def run_experiment(
+        self, days: int, start: Optional[str] = None, assignment=False
+    ) -> dict:
         """Add experimental student data to repository.
 
         Parameters
@@ -93,9 +95,19 @@ class Experiment:
         if start is None:
             start = pd.Timestamp.now()
         if assignment:
-            self.cohort = Cohort(days=days, start=start, is_experiment=True, cohort_params=cohort_params_assignment)
+            self.cohort = Cohort(
+                days=days,
+                start=start,
+                is_experiment=True,
+                cohort_params=cohort_params_assignment,
+            )
         else:
-            self.cohort = Cohort(days=days, start=start, is_experiment=True, cohort_params=cohort_params)
+            self.cohort = Cohort(
+                days=days,
+                start=start,
+                is_experiment=True,
+                cohort_params=cohort_params,
+            )
         r = self.add_cohort_to_repository()
         return r
 
