@@ -274,264 +274,253 @@ cohort_params = {
 cohort_params_assignment = {
     "demographics": {
         "age": {
-            "18": 0.026588288491973772,
-            "19": 0.038525887406737507,
-            "20": 0.04567035948451277,
-            "21": 0.056929685733664935,
-            "22": 0.06651593940764187,
-            "23": 0.06895772100384355,
-            "24": 0.07108297535609315,
-            "25": 0.06511417589871128,
-            "26": 0.0617228125706534,
-            "27": 0.05616097671263848,
-            "28": 0.050463486321501244,
-            "29": 0.04567035948451277,
-            "30": 0.040018087271082976,
-            "31": 0.03513452407867963,
-            "32": 0.03400406963599367,
-            "33": 0.028216142889441555,
-            "34": 0.0259100158263622,
-            "35": 0.022382997965182002,
-            "36": 0.01994121636898033,
-            "37": 0.01912728917024644,
-            "38": 0.018132489260682793,
-            "39": 0.016414198507800137,
-            "40": 0.01320370789057201,
-            "41": 0.011394980782274475,
-            "42": 0.010716708116662898,
-            "43": 0.00845579923129098,
-            "44": 0.006556635767578567,
-            "45": 0.005561835858014922,
-            "46": 0.004928781370110784,
-            "47": 0.0047026904815735925,
-            "48": 0.003843545105132263,
-            "49": 0.002306127063079358,
-            "50": 0.0023965634184942345,
-            "51": 0.002306127063079358,
-            "52": 0.0019895998191272893,
-            "53": 0.0011304544426859599,
-            "54": 0.0008591453764413295,
-            "55": 0.0009947999095636447,
-            "56": 0.0009495817318562062,
-            "57": 0.000813927198733891,
-            "58": 0.0011756726203933981,
-            "59": 0.0005878363101966991,
-            "60": 0.0006330544879041374,
-            "61": 0.00036174542165950713,
-            "62": 0.00027130906624463035,
-            "63": 0.0004069635993669455,
-            "64": 9.043635541487678e-05,
-            "65": 9.043635541487678e-05,
-            "66": 4.521817770743839e-05,
-            "67": 4.521817770743839e-05,
-            "68": 9.043635541487678e-05,
-            "69": 4.521817770743839e-05,
-            "70": 9.043635541487678e-05,
-            "72": 9.043635541487678e-05,
-            "73": 9.043635541487678e-05,
-            "74": 4.521817770743839e-05,
-            "76": 4.521817770743839e-05,
+            "18": 0.0083875385,
+            "19": 0.012067785,
+            "20": 0.0184868196,
+            "21": 0.0297843204,
+            "22": 0.0478432044,
+            "23": 0.0600821636,
+            "24": 0.0701814447,
+            "25": 0.0667579596,
+            "26": 0.0623930161,
+            "27": 0.0578568983,
+            "28": 0.054946936,
+            "29": 0.050239644,
+            "30": 0.0457035262,
+            "31": 0.0397980144,
+            "32": 0.0404827114,
+            "33": 0.0297843204,
+            "34": 0.0299554947,
+            "35": 0.0261040739,
+            "36": 0.0277302294,
+            "37": 0.0249914413,
+            "38": 0.0226805888,
+            "39": 0.0211400205,
+            "40": 0.0162615543,
+            "41": 0.0166039028,
+            "42": 0.0132660048,
+            "43": 0.012067785,
+            "44": 0.0122389593,
+            "45": 0.0092434098,
+            "46": 0.0095001712,
+            "47": 0.0092434098,
+            "48": 0.0079596029,
+            "49": 0.0051352277,
+            "50": 0.005391989,
+            "51": 0.0047928792,
+            "52": 0.0041937693,
+            "53": 0.0025676138,
+            "54": 0.003337898,
+            "55": 0.0035946594,
+            "56": 0.002653201,
+            "57": 0.0022252653,
+            "58": 0.0020540911,
+            "59": 0.0023108524,
+            "60": 0.0017117426,
+            "61": 0.0002567614,
+            "62": 0.0004279356,
+            "63": 0.0008558713,
+            "64": 0.0005135228,
+            "65": 0.0009414584,
+            "66": 0.0005135228,
+            "67": 0.000684697,
+            "68": 0.000684697,
+            "69": 0.0001711743,
+            "70": 0.0003423485,
+            "71": 0.0003423485,
+            "72": 0.0000855871,
+            "73": 0.0001711743,
+            "75": 0.0000855871,
+            "76": 0.0000855871,
+            "78": 0.0000855871,
         },
         "admissionsQuiz": {
-            "incomplete": 0.27,
-            "complete": 0.73,
+            "incomplete": 0.23,
+            "complete": 0.77,
         },
         "countryISO2": {
-            "AD": 9.044044496698923e-05,
-            "AE": 0.00018088088993397847,
-            "AF": 0.014244370082300804,
-            "AG": 4.522022248349462e-05,
-            "AI": 4.522022248349462e-05,
-            "AL": 0.0015827077869223116,
-            "AM": 0.0006783033372524192,
-            "AO": 0.0008139640047029031,
-            "AR": 0.0005878628922854301,
-            "AS": 0.00018088088993397847,
-            "AT": 4.522022248349462e-05,
-            "AU": 0.0011757257845708602,
-            "AX": 0.0017183684543727955,
-            "AZ": 0.0015827077869223116,
-            "BA": 9.044044496698923e-05,
-            "BB": 0.00013566066745048386,
-            "BD": 0.04856651894727322,
-            "BE": 0.00036176177986795694,
-            "BF": 0.0006330831147689246,
-            "BG": 0.0005426426698019355,
-            "BI": 0.0012661662295378492,
-            "BJ": 0.003572397576196075,
-            "BO": 9.044044496698923e-05,
-            "BR": 0.003074975128877634,
-            "BS": 4.522022248349462e-05,
-            "BT": 0.0010400651171203763,
-            "BW": 0.0037532784661300535,
-            "BY": 0.00018088088993397847,
-            "BZ": 4.522022248349462e-05,
-            "CA": 0.0028036537939766662,
-            "CD": 0.0028940942389436555,
-            "CF": 0.00027132133490096773,
-            "CG": 0.0006783033372524192,
-            "CH": 0.0002261011124174731,
-            "CI": 0.0020801302342407526,
-            "CL": 0.00027132133490096773,
-            "CM": 0.01135027584335715,
-            "CN": 0.009179705164149407,
-            "CO": 0.0013566066745048385,
-            "CR": 0.00027132133490096773,
-            "CV": 0.00013566066745048386,
-            "CX": 9.044044496698923e-05,
-            "CY": 0.0002261011124174731,
-            "CZ": 9.044044496698923e-05,
-            "DE": 0.0017183684543727955,
-            "DJ": 0.00040698200235145157,
-            "DK": 9.044044496698923e-05,
-            "DM": 0.00013566066745048386,
-            "DO": 0.0002261011124174731,
-            "DZ": 0.004205480690965,
-            "EC": 0.00018088088993397847,
-            "EG": 0.00714479515239215,
-            "EH": 4.522022248349462e-05,
-            "ER": 0.0006330831147689246,
-            "ES": 0.0011305055620873655,
-            "ET": 0.042371348467034456,
-            "FI": 9.044044496698923e-05,
-            "FJ": 0.0008591842271863978,
-            "FR": 0.00040698200235145157,
-            "GA": 0.00036176177986795694,
-            "GB": 0.003708058243646559,
-            "GE": 0.00013566066745048386,
-            "GH": 0.03183503662838021,
-            "GM": 0.003934159356064032,
-            "GN": 0.0007687437822194085,
-            "GQ": 9.044044496698923e-05,
-            "GR": 0.0007235235597359139,
-            "GS": 9.044044496698923e-05,
-            "GT": 0.0002261011124174731,
-            "GW": 0.00018088088993397847,
-            "GY": 9.044044496698923e-05,
-            "HK": 0.0012661662295378492,
-            "HN": 4.522022248349462e-05,
-            "HR": 0.00013566066745048386,
-            "HT": 0.0003165415573844623,
-            "HU": 0.0006330831147689246,
-            "ID": 0.009767568056434838,
-            "IE": 0.00018088088993397847,
-            "IL": 0.00027132133490096773,
-            "IM": 4.522022248349462e-05,
-            "IN": 0.10409695215700461,
-            "IO": 0.0004522022248349462,
-            "IQ": 0.0029845346839106448,
-            "IS": 4.522022248349462e-05,
-            "IT": 0.0011757257845708602,
-            "JM": 0.0004974224473184408,
-            "JO": 0.000949624672153387,
-            "JP": 0.00018088088993397847,
-            "KE": 0.05340508275300714,
-            "KG": 0.0004974224473184408,
-            "KH": 0.0004974224473184408,
-            "KI": 4.522022248349462e-05,
-            "KM": 0.00027132133490096773,
-            "KR": 0.0009948448946368817,
-            "KZ": 0.0008139640047029031,
-            "LA": 4.522022248349462e-05,
-            "LB": 0.0012661662295378492,
-            "LK": 0.0064664918151397304,
-            "LR": 0.006149950257755268,
-            "LS": 0.004431581803382473,
-            "LT": 0.00013566066745048386,
-            "LU": 4.522022248349462e-05,
-            "LV": 4.522022248349462e-05,
-            "LY": 0.0011757257845708602,
-            "MA": 0.003210635796328118,
-            "ME": 4.522022248349462e-05,
-            "MG": 0.000949624672153387,
-            "MK": 9.044044496698923e-05,
-            "ML": 0.0010400651171203763,
-            "MM": 0.002125350456724247,
-            "MN": 0.0005878628922854301,
-            "MO": 9.044044496698923e-05,
-            "MR": 0.0004522022248349462,
-            "MU": 0.0009044044496698924,
-            "MV": 9.044044496698923e-05,
-            "MW": 0.010988514063489193,
-            "MX": 0.002034910011757258,
-            "MY": 0.0033915166862620964,
-            "MZ": 0.0018088088993397848,
-            "NA": 0.0017183684543727955,
-            "NE": 0.000949624672153387,
-            "NG": 0.23057791444333905,
-            "NI": 4.522022248349462e-05,
-            "NL": 0.00036176177986795694,
-            "NO": 0.00018088088993397847,
-            "NP": 0.010988514063489193,
-            "NZ": 0.00013566066745048386,
-            "OM": 4.522022248349462e-05,
-            "PA": 0.00013566066745048386,
-            "PE": 0.0006783033372524192,
-            "PG": 0.002170570679207742,
-            "PH": 0.021117843899791988,
-            "PK": 0.12200416026046848,
-            "PL": 0.001085285339603871,
-            "PR": 0.0002261011124174731,
-            "PS": 9.044044496698923e-05,
-            "PT": 0.00013566066745048386,
-            "QA": 4.522022248349462e-05,
-            "RO": 0.0006330831147689246,
-            "RS": 0.00013566066745048386,
-            "RU": 0.002261011124174731,
-            "RW": 0.00958668716650086,
-            "SA": 0.00018088088993397847,
-            "SB": 9.044044496698923e-05,
-            "SD": 0.0008591842271863978,
-            "SE": 0.00013566066745048386,
-            "SG": 0.0046124626933164515,
-            "SI": 0.00013566066745048386,
-            "SK": 0.00013566066745048386,
-            "SL": 0.009134484941665914,
-            "SN": 0.0014470471194718277,
-            "SO": 0.008682282716830967,
-            "SS": 0.002577552681559193,
-            "ST": 9.044044496698923e-05,
-            "SV": 9.044044496698923e-05,
-            "SZ": 0.0031654155738446233,
-            "TD": 0.0012209460070543548,
-            "TG": 0.0019896897892737633,
-            "TH": 0.0017183684543727955,
-            "TJ": 0.00036176177986795694,
-            "TK": 4.522022248349462e-05,
-            "TL": 0.0003165415573844623,
-            "TM": 0.0002261011124174731,
-            "TN": 0.003210635796328118,
-            "TO": 0.00013566066745048386,
-            "TR": 0.003210635796328118,
-            "TT": 0.00018088088993397847,
-            "TV": 4.522022248349462e-05,
-            "TW": 0.0007687437822194085,
-            "TZ": 0.009451026499050375,
-            "UA": 0.0010400651171203763,
-            "UG": 0.013656507190015375,
-            "US": 0.018540291218232793,
-            "UZ": 0.002034910011757258,
-            "VE": 0.00036176177986795694,
-            "VI": 4.522022248349462e-05,
-            "VN": 0.009179705164149407,
-            "VU": 9.044044496698923e-05,
-            "WS": 0.00013566066745048386,
-            "YE": 0.0011757257845708602,
-            "ZA": 0.013159084742696935,
-            "ZM": 0.013159084742696935,
-            "ZW": 0.02066564167495704,
+            "NG": 0.1854134566,
+            "IN": 0.1194144838,
+            "PK": 0.1128231467,
+            "ET": 0.0592364321,
+            "GH": 0.0575243965,
+            "BD": 0.0455401472,
+            "KE": 0.0402328368,
+            "UG": 0.0261941448,
+            "ZW": 0.0243965074,
+            "TZ": 0.0173771614,
+            "PH": 0.0147235062,
+            "NP": 0.0147235062,
+            "AF": 0.0130970724,
+            "CM": 0.0114706386,
+            "ZA": 0.0113850368,
+            "DZ": 0.0113850368,
+            "US": 0.010529019,
+            "CN": 0.0104434172,
+            "SO": 0.0103578154,
+            "RW": 0.0100154083,
+            "ZM": 0.0098442048,
+            "VN": 0.0090737887,
+            "EG": 0.0086457798,
+            "MA": 0.0086457798,
+            "LK": 0.0086457798,
+            "ID": 0.0076185585,
+            "SL": 0.0066769389,
+            "MW": 0.0059065229,
+            "IQ": 0.0058209211,
+            "TN": 0.0056497175,
+            "BW": 0.0055641157,
+            "SG": 0.0039376819,
+            "GB": 0.0036808766,
+            "MY": 0.0035952748,
+            "AL": 0.0035952748,
+            "CD": 0.0033384694,
+            "LR": 0.0032528677,
+            "JO": 0.0028248588,
+            "LS": 0.0028248588,
+            "SN": 0.002739257,
+            "TR": 0.0026536552,
+            "LB": 0.0025680534,
+            "BR": 0.0024824516,
+            "CA": 0.0023968499,
+            "BJ": 0.0023968499,
+            "TH": 0.0023112481,
+            "HK": 0.0023112481,
+            "YE": 0.0023112481,
+            "RU": 0.0022256463,
+            "AX": 0.0021400445,
+            "MM": 0.0021400445,
+            "UZ": 0.0021400445,
+            "CI": 0.0017976374,
+            "GM": 0.0017976374,
+            "MZ": 0.0017976374,
+            "TG": 0.001540832,
+            "AZ": 0.0014552303,
+            "SZ": 0.0014552303,
+            "GE": 0.0014552303,
+            "IT": 0.0014552303,
+            "PG": 0.0013696285,
+            "SS": 0.0012840267,
+            "MX": 0.0012840267,
+            "AU": 0.0011984249,
+            "RO": 0.0011984249,
+            "AO": 0.0011128231,
+            "GR": 0.0011128231,
+            "LY": 0.0010272214,
+            "FJ": 0.0010272214,
+            "KR": 0.0010272214,
+            "TD": 0.0010272214,
+            "MU": 0.0010272214,
+            "UA": 0.0010272214,
+            "BI": 0.0009416196,
+            "ES": 0.0009416196,
+            "DE": 0.000770416,
+            "FR": 0.000770416,
+            "JM": 0.0006848142,
+            "SD": 0.0006848142,
+            "CO": 0.0006848142,
+            "MG": 0.0005992125,
+            "BE": 0.0005992125,
+            "ML": 0.0005992125,
+            "ER": 0.0005992125,
+            "KH": 0.0005992125,
+            "HU": 0.0005136107,
+            "BF": 0.0005136107,
+            "NE": 0.0005136107,
+            "GN": 0.0004280089,
+            "TL": 0.0004280089,
+            "CF": 0.0004280089,
+            "MR": 0.0004280089,
+            "SA": 0.0004280089,
+            "KZ": 0.0004280089,
+            "TW": 0.0004280089,
+            "KG": 0.0004280089,
+            "JP": 0.0004280089,
+            "PT": 0.0003424071,
+            "AM": 0.0003424071,
+            "AT": 0.0003424071,
+            "IE": 0.0003424071,
+            "RS": 0.0003424071,
+            "MN": 0.0003424071,
+            "CL": 0.0003424071,
+            "PS": 0.0002568053,
+            "PL": 0.0002568053,
+            "PE": 0.0002568053,
+            "TJ": 0.0002568053,
+            "LA": 0.0002568053,
+            "CZ": 0.0002568053,
+            "NZ": 0.0002568053,
+            "BY": 0.0002568053,
+            "CG": 0.0002568053,
+            "DJ": 0.0002568053,
+            "MK": 0.0002568053,
+            "EC": 0.0002568053,
+            "VE": 0.0002568053,
+            "AS": 0.0002568053,
+            "AR": 0.0002568053,
+            "IO": 0.0002568053,
+            "SK": 0.0002568053,
+            "MV": 0.0001712036,
+            "HN": 0.0001712036,
+            "BO": 0.0001712036,
+            "NL": 0.0001712036,
+            "BH": 0.0001712036,
+            "GA": 0.0001712036,
+            "LT": 0.0001712036,
+            "AE": 0.0001712036,
+            "BA": 0.0001712036,
+            "EE": 0.0001712036,
+            "IL": 0.0001712036,
+            "HR": 0.0001712036,
+            "NI": 0.0001712036,
+            "SB": 0.0001712036,
+            "KM": 0.0001712036,
+            "KI": 0.0001712036,
+            "GW": 0.0001712036,
+            "VU": 0.0000856018,
+            "SX": 0.0000856018,
+            "BG": 0.0000856018,
+            "OM": 0.0000856018,
+            "DM": 0.0000856018,
+            "TM": 0.0000856018,
+            "KW": 0.0000856018,
+            "IM": 0.0000856018,
+            "CV": 0.0000856018,
+            "DK": 0.0000856018,
+            "UM": 0.0000856018,
+            "LV": 0.0000856018,
+            "WS": 0.0000856018,
+            "GQ": 0.0000856018,
+            "UY": 0.0000856018,
+            "NO": 0.0000856018,
+            "SJ": 0.0000856018,
+            "LC": 0.0000856018,
+            "EH": 0.0000856018,
+            "ME": 0.0000856018,
+            "BT": 0.0000856018,
+            "ST": 0.0000856018,
+            "SR": 0.0000856018,
+            "PY": 0.0000856018,
+            "HT": 0.0000856018,
+            "AD": 0.0000856018,
+            "BB": 0.0000856018,
+            "AG": 0.0000856018,
+            "CR": 0.0000856018,
+            "MO": 0.0000856018,
+            "CH": 0.0000856018,
+            "CY": 0.0000856018,
         },
         "gender": {
-            "female": 0.2476491946746113,
-            "male": 0.7498370728982404,
-            "other": 0.00251373242714831,
+            "male": 0.8077317824,
+            "female": 0.1898734177,
+            "other": 0.0023947999,
         },
         "highestDegreeEarned": {
-            "Bachelor's degree": 0.5158722980917066,
-            "Doctorate (e.g. PhD)": 0.015239214976937686,
-            "High School or Baccalaureate": 0.16419462783756897,
-            "Master's degree": 0.18183051460613187,
-            "Some College (1-3 years)": 0.12286334448765487,
+            "Bachelor's degree": 0.7253292287,
+            "Master's degree": 0.2531212588,
+            "Doctorate (e.g. PhD)": 0.0199247477,
+            "Some College (1-3 years)": 0.0008551394,
+            "High School or Baccalaureate": 0.0007696254,
         },
     },
     "experiment": {
